@@ -4,6 +4,9 @@
     使用parser.CommandParser类创建对象，根据情况调用tryParse或parse解析指令
 """
 
-from .command import Command,cmdCallback,commandPrefix
-from .parser import CommandParser
+from .__version__ import __version__
+from .command import Command,OPT,CommandParser,ParseResult,CommandCore
+from .event import Events
+# Parser=CommandParser
+# Core=CommandCore
 #这样就可以 from LSParser import *
\ No newline at end of file
