@@ -1,2 +1,2 @@
 from . import str_similarity
-from .str import *
\ No newline at end of file
+# from .str import *
\ No newline at end of file
